# Note that gerris is distributed in the form of snapshot tarballs of
# the darcs development tree at various intervals. Unfortunately the
# snapshot tarball name does not contain any version information.  For
# packaging, the version information taken from configure.in - see
# GFS_MAJOR_VERSION, GFS_MINOR_VERSION, GFS_MICRO_VERSION

# Downloads are available from:
# http://gerris.dalembert.upmc.fr/gerris/tarballs/
%global snapshot 111123

Name:		 gerris
Version:	 1.3.2
Release:	 3.20%{snapshot}%{?dist}
Summary: 	 The Gerris Flow Solver

Group: 		 Applications/Engineering
License: 	 GPLv2
URL: 		 http://gfs.sourceforge.net

Source0: 	 http://gerris.dalembert.upmc.fr/gerris/tarballs/%{name}-snapshot-%{snapshot}.tar.gz
BuildRoot: 	 %{_tmppath}/%{name}-%{version}-%{release}-root-%(%{__id_u} -n)

BuildRequires: 	 netcdf-devel proj-devel gcc-gfortran
BuildRequires: 	 gsl-devel gts-devel openmpi-devel hdf5-openmpi-devel
BuildRequires:	 ode-devel fftw-devel

BuildRequires:   emacs

# We do really require the -devel package as Gerris performs on the fly compilation of functions
# https://groups.google.com/group/gerris-devel/browse_thread/thread/5fc0c66332abe09f?hl=en
Requires:      	 %{name}-devel = %{version}-%{release}
Requires:      	 %{name}-libs = %{version}-%{release}

Requires:      	 proj gsl netcdf hdf5-openmpi
Requires:      	 hicolor-icon-theme

# For Fedora 15 and lower, and for EL6 we need to split out the emacs
# support into a sub-package. For Fedora 16 and later keep the emacs
# support files in the main package and require the emacs-filesystem
# package
%if 0%{?fedora} >= 16
Requires:      	 emacs-filesystem >= %{_emacs_version}
%endif

%description
Gerris is an Open Source Free Software library for the solution of the
partial differential equations describing fluid flow. A brief summary
of its main (current) features:

* Quadtree-based (Octree in 3D) spatial discretisation with
  automatic and dynamic refinement.
* Multigrid Poisson solver.
* Second-order Godunov type advection scheme.
* Solves the time-dependent incompressible Euler, Stokes ans Navier-Stokes
  equations.
* Support for complex solid boundaries (automatic locally-refined
  mesh generation).

%package libs
Summary:	Gerris shared libraries
Group: 		Applications/Engineering

%description libs
Shared libraries for the Gerris project.

%package devel
Summary:	Headers and libraries for The Gerris Flow Solver (development snapshot)
Group: 		Applications/Engineering
Requires: 	%{name}-libs%{?_isa} = %{version}-%{release}
Requires: 	gts-devel openmpi-devel
Requires: 	pkgconfig

%description devel
Header files, doc, faq and demos files for The Gerris Flow Solver.

%if 0%{?fedora} < 16 || 0%{?rhel}
%package -n emacs-%{name}
Summary:	Emacs mode for editing Gerris input files
Group:		Applications/Editors
BuildArch:      noarch
Requires:       emacs(bin) >= %{_emacs_version}

%description -n emacs-%{name}
Emacs mode for editing Gerris input files.
%endif

%prep
%setup -q -n %{name}-snapshot-%{snapshot}
 
%build
%_openmpi_load

# Note the configure script doesn't honor --disable-rpath
%configure
# So disable rpath
sed -i 's|^hardcode_libdir_flag_spec=.*|hardcode_libdir_flag_spec=""|g' libtool
sed -i 's|^runpath_var=LD_RUN_PATH|runpath_var=DIE_RPATH_DIE|g' libtool

make %{?_smp_mflags}

# Byte compile Emacs mode
# Unfortunately byte compilation is currently broken
#{_emacs_bytecompile} doc/examples/gfs-mode.el

%install
rm -rf $RPM_BUILD_ROOT
%_openmpi_load
make install DESTDIR=$RPM_BUILD_ROOT

# Remove libtool archive files
find $RPM_BUILD_ROOT -name *.la -exec rm -f {} \;

# Remove shared libs
find $RPM_BUILD_ROOT -name *.a -exec rm -f {} \;

# Remove this as it's a convenience script for the gerris developers
rm -f $RPM_BUILD_ROOT%{_bindir}/darcs2dist

# Properly install the Emacs elisp files and byte compile them
install -d $RPM_BUILD_ROOT%{_emacs_sitelispdir}/%{name}
install -m 644 doc/examples/gfs-mode.el $RPM_BUILD_ROOT%{_emacs_sitelispdir}/%{name}
#install -m 644 doc/examples/gfs-mode.elc $RPM_BUILD_ROOT%{_emacs_sitelispdir}/%{name}

# Remove incorrectly located elisp file
rm -f $RPM_BUILD_ROOT%{_datadir}/gerris/gfs-mode.el

# Load gfs-mode on start-up of Emacs
install -d $RPM_BUILD_ROOT%{_emacs_sitestartdir}
cat > $RPM_BUILD_ROOT%{_emacs_sitestartdir}/gerris.el <<EOF
(require 'gfs-mode)
EOF

%clean
rm -rf $RPM_BUILD_ROOT

%post
/bin/touch --no-create %{_datadir}/icons/hicolor &>/dev/null || :
/usr/bin/update-mime-database %{_datadir}/mime &> /dev/null || :

%postun
if [ $1 -eq 0 ] ; then
    /bin/touch --no-create %{_datadir}/icons/hicolor &>/dev/null
    /usr/bin/gtk-update-icon-cache %{_datadir}/icons/hicolor &>/dev/null || :
fi
/usr/bin/update-mime-database %{_datadir}/mime &> /dev/null || :

%posttrans
/usr/bin/gtk-update-icon-cache %{_datadir}/icons/hicolor &>/dev/null || :

%post libs -p /sbin/ldconfig

%postun libs -p /sbin/ldconfig


%files
%defattr(-,root,root,-)
%doc NEWS README TODO COPYING
%{_bindir}/*
%{_libdir}/gerris/
%{_datadir}/gerris/
%{_datadir}/mime/packages/*.xml
%{_datadir}/icons/hicolor/48x48/mimetypes/*.png
%{_mandir}/man1/*.gz

%files libs
%defattr(-,root,root,-)
%doc NEWS README TODO COPYING
%{_libdir}/*.so.*

%files devel
%defattr(-,root,root,-)
%{_includedir}/*.h
%{_includedir}/gerris/
%{_libdir}/pkgconfig/*.pc
%{_libdir}/*.so

%if 0%{?fedora} < 16 || 0%{?rhel}
%files -n emacs-%{name}
%defattr(-,root,root,-)
%{_emacs_sitelispdir}/%{name}
%{_emacs_sitestartdir}/gerris.el
%endif

%changelog
* Mon Dec  5 2011 Jonathan G. Underwood <jonathan.underwood@gmail.com> - 1.3.2-3.20111123
- Add support for Fedora 16 and greater where we don't need to split
  out the emacs-gerris sub-package

* Mon Dec  5 2011 Jonathan G. Underwood <jonathan.underwood@gmail.com> - 1.3.2-2.20111123
- Enable fftw and ode plugins

* Mon Dec  5 2011 Jonathan G. Underwood <jonathan.underwood@gmail.com> - 1.3.2-1.20111123
- Properly package Emacs mode in a subpackage and ensure it's loaded at Emacs start

* Mon Dec  5 2011 Jonathan G. Underwood <jonathan.underwood@gmail.com> - 1.3.2-0.20111123
- Initial package

